@@ -1,11 +1,19 @@
 /* conf.c -  
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <errno.h>
 #include <stdio.h>
+#include <stdio.h>
+#include <fcntl.h>		/* old method of redirecting stdin */
+#include <sys/stat.h>		/* old method of redirecting stdin */
 #include <stdlib.h>
 #include <string.h>
 #include <strings.h>
+#include <unistd.h>
 
 #include "conf.h"
 
@@ -26,10 +34,9 @@ int
 conf_read_file (param_t *parameter_list, char *file)
 {
   int    fd, stdin_fd; 
-  FILE   *fp; 
+  FILE   *fp; 			/* Might be used later when NetBSD works... */
   param_t *p;
   int result;
-  extern FILE *yyin;
 
   if (!parameter_list)
     {
@@ -37,29 +44,46 @@ conf_read_file (param_t *parameter_list, char *file)
       return -1;
     }
 
-   stdin_fd = fileno(stdin);   /*save descriptor for 'stdin' */ 
-   fd       = dup(stdin_fd); 
+   stdin_fd = fileno (stdin);   /* save descriptor for 'stdin' */ 
+   fd       = dup (stdin_fd); 
  
    if (fd == -1) 
       return -1;               /* failed to duplicate input descriptor */ 
  
+#if 0 /* Does not work on NetBSD 1.6 */
    /* use the duplicated descriptor to redirect input... */ 
    fp = fdopen (fd, "r"); 
  
    if (!fp) 
       return -2;               /* failed to open duplicated descriptor */ 
  
-   stdin = freopen (file, "r", fp); 
- 
+   stdin = freopen (file, "r", fp);
+
    if (!stdin) 
       return -3;               /* failed to redirect stream input */ 
+#else /* Revert to older method */
+   {
+     int temp_fd;
+
+     temp_fd = open (file, O_RDWR, S_IREAD);
+
+     dup2 (temp_fd, stdin_fd);
+
+     close (temp_fd);
+   }
+#endif
  
    result = yyparse ((void *)parameter_list);
 
    /* UNDO: now undo the effects of redirecting input... */ 
+#if 0 /* Does not work on NetBSD 1.6 */
    fclose(stdin); 
  
-   stdin = fdopen(stdin_fd, "r"); 
+   stdin = fdopen (stdin_fd, "r"); 
+#else /* Revert to older method */
+   dup2 (fd, stdin_fd);
+   close (fd);
+#endif
  
    if (!stdin) 
       return -4;               /* failed to reestablish 'stdin' */ 
@@ -123,10 +147,13 @@ conf_find_key (param_t *parameter_list, char *key)
 
 /* Our very own strndup(), this should go into a compatibility lib. */
 static char *
-copy_string (char *src, size_t len)
+strlndup (char *src, size_t len)
 {
   char *dst;
 
+  if (!src)			/* Cannot copy non-existing string. */
+    return NULL;
+
   dst = malloc (len + 1);
   if (!dst)
     return NULL;
@@ -139,6 +166,38 @@ copy_string (char *src, size_t len)
 }
 
 
+/**
+ * strlncpy - Rip-off from OpenBSD's strlcpy()
+ * @dst: Destination string.
+ * @src: Source string.
+ * @len: maximum number of char's to copy.
+ *
+ * XXX - Relies on dst being valid 
+ * Makes sure to NUL terminate dst when done.
+ */
+
+static size_t
+strlncpy (char *dst, char *src, size_t len)
+{
+  size_t src_len = strlen (src);
+
+  if (src_len > len)
+    src_len = len;
+
+  strncpy (dst, src, src_len);
+
+  dst[src_len] = '\0';
+
+  return src_len;
+}
+
+
+/* TODO: Implement strlncat() or setup proper aliases for 
+ * OpenBSD's strlcpy() strlcat() if configure does not find
+ * support for them or libsafe <--- Lucent contribution.
+ */
+
+
 /* XXX - what if the key doesn't exist?
  * XXX - signal for bogus config file?
  */
@@ -147,6 +206,7 @@ conf_set_value (param_t *parameter_list, char *key, char *value)
 {
   int result;
   param_t *parm;
+  char    *orig_value = value;
 
   /* Check if Flex failed to allocate a new string. */
   if (!key || !value)
@@ -164,23 +224,27 @@ conf_set_value (param_t *parameter_list, char *key, char *value)
       char *str;
 
       /* Cleanup of argument. It can be any of the following:
-       * value
-       * "value"
-       * value;
-       * "value";
+       * value     len=6
+       * "value"   len=8
+       * value;"   len=7
+       * "value";  len=9
        */
-      if (value [len - 1] == ';')
+      if (len > 0 && value [len - 1] == ';')
 	len --;
 
-      if (value [0] == '"' && value [len - 1] == '"')
+      if (len > 1 && value [0] == '"' && value [len - 1] == '"')
 	{
-	  len -= 2;
+	  len -= 1;
 	  value++;
 	}
 
-      str = copy_string (value, len);
+      str = strlndup (value, len);
 
-      free (value);
+      /* Free the string strdup():ed by flex, not the one
+       * we might have been messing around with, pointer-wise.
+       * XXX - Interface-wise this is not very good, flex should do it.
+       */
+      free (orig_value);
 
       parm->value = str;
       result  = 0;
