@@ -70,28 +70,47 @@
 /* Copy the first part of user declarations.  */
 #line 2 "conf/parser.y"
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdio.h>
 
 #include "conf.h"
 #include "config.h"
 
+#ifdef DEBUG
+#define log(args...) fprintf (stderr, args);
+#else
+#define log(args...)
+#endif
+
 extern int yylex (void);
-extern int yyget_lineno (void);
 
 /* Defines needed for a pure reentrant parser/lexer.
    These are dsiabled for now due to failure to realize.
    #define YYLEX_PARAM   foo
  */
 #define YYPARSE_PARAM list
+
+#if 0 /* Not yet reentrant ... 
+       * reverting in the meantime for the sake of cygwin port 
+       */
+extern int yyget_lineno (void);
 #define yylineno      yyget_lineno ()
+#else
+extern int yylineno;
+#endif
 
 int yyerror (char *s)
 {
-  fprintf (stderr, "ERROR: %s\n", s);
+  /* XXX - Add filename to syntax error message. */
+  fprintf (stderr, "<filename>:%d -- %s\n", yylineno, s);
 
   return -1;
 }
 
+/* XXX - Add filename to syntax error message. */
 #define conf_set(key,value)				\
   if (conf_set_value ((param_t *)list, key, value))	\
     fprintf (stderr,					\
@@ -115,12 +134,12 @@ int yyerror (char *s)
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 36 "conf/parser.y"
+#line 55 "conf/parser.y"
 typedef union YYSTYPE {
 	char *str;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 124 "parser.c"
+#line 143 "parser.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -132,7 +151,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 136 "parser.c"
+#line 155 "parser.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -299,7 +318,7 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    45,    45,    46,    49,    50,    53,    55
+       0,    64,    64,    65,    68,    69,    72,    74
 };
 #endif
 
@@ -997,14 +1016,14 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-#line 53 "conf/parser.y"
-    {/* printf ("\nBison(ID:%s)(ARG:%s)", $1, $3); */
+#line 72 "conf/parser.y"
+    {log ("\nBison(ID:%s)(ARG:%s)", yyvsp[-2].str, yyvsp[0].str);
                                  conf_set (yyvsp[-2].str, yyvsp[0].str);}
     break;
 
   case 7:
-#line 55 "conf/parser.y"
-    {/* printf ("%s(%s)\n", $1, $2); */
+#line 74 "conf/parser.y"
+    {log ("%s(%s)\n", yyvsp[-1].str, yyvsp[0].str);
                                  conf_set (yyvsp[-1].str, yyvsp[0].str);}
     break;
 
@@ -1012,7 +1031,7 @@ yyreduce:
     }
 
 /* Line 999 of yacc.c.  */
-#line 1016 "parser.c"
+#line 1035 "parser.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1206,7 +1225,7 @@ yyreturn:
 }
 
 
-#line 59 "conf/parser.y"
+#line 78 "conf/parser.y"
 
 
 
