@@ -135,13 +135,15 @@ void print_parm (param_t *p)
 config_data_t *
 config_load (char *file)
 {
+  int result;
   char *temp;
 
   /* Setup default configuration */
   file = config_locate (file);
 
   /* Fill in the blanks by reading the conf file */
-  if (-1 == conf_read_file (parms, file))
+  result = conf_read_file (parms, file);
+  if (result < 0)
     {
       fprintf (stderr, "Cannot find configuration file %s: %s\n", 
                file, strerror (errno));
@@ -186,9 +188,29 @@ config_load (char *file)
     }
 
   __config_area.daemon_start = conf_get_bool (parms, "DEAMON_S");
-  __config_area.daemon_type  = strcasecmp (conf_get_value (parms, "DEAMON_S"), "login") ? 1 : 0;
-  __config_area.daemon_delay = atoi (conf_get_value (parms, "DEAMON_D"));
+  
+  temp = conf_get_value (parms, "DEAMON_T");
+  if (!temp)
+    {
+      __config_area.daemon_type  = 1;
+    }
+  else
+    {
+      __config_area.daemon_type  = strcasecmp (temp, "login") ? 1 : 0;
+    }
 
+  temp = conf_get_value (parms, "DEAMON_D");
+  if (!temp)
+    {
+      __config_area.daemon_delay = 20; /* XXX - hardcoded to fix buggy conf_get_value() that returns NULL when no
+					conf file is found.
+				       */
+    }
+  else
+    {
+      __config_area.daemon_delay = atoi (temp);
+    }
+  
   __config_area.username     = conf_get_value (parms, "USER");
   __config_area.password     = conf_get_value (parms, "PASS");
 
